# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from . import Common_pb2 as Common__pb2
from . import LogReplayNode_pb2 as LogReplayNode__pb2


class LogReplayNodeStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.StartLog = channel.unary_unary(
                '/LogReplayNode.LogReplayNode/StartLog',
                request_serializer=Common__pb2.file_path.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.GetLogInfo = channel.unary_unary(
                '/LogReplayNode.LogReplayNode/GetLogInfo',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=LogReplayNode__pb2.log_info.FromString,
                )
        self.StopLog = channel.unary_unary(
                '/LogReplayNode.LogReplayNode/StopLog',
                request_serializer=Common__pb2.file_path.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.DecodeLin = channel.unary_unary(
                '/LogReplayNode.LogReplayNode/DecodeLin',
                request_serializer=LogReplayNode__pb2.lin_message.SerializeToString,
                response_deserializer=LogReplayNode__pb2.lin_message_decode.FromString,
                )
        self.DecodeCan = channel.unary_unary(
                '/LogReplayNode.LogReplayNode/DecodeCan',
                request_serializer=LogReplayNode__pb2.can_message.SerializeToString,
                response_deserializer=LogReplayNode__pb2.can_message_decode.FromString,
                )
        self.AddLinDecodeRole = channel.unary_unary(
                '/LogReplayNode.LogReplayNode/AddLinDecodeRole',
                request_serializer=LogReplayNode__pb2.lin_decode_role.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.AddCanDecodeRole = channel.unary_unary(
                '/LogReplayNode.LogReplayNode/AddCanDecodeRole',
                request_serializer=LogReplayNode__pb2.can_decode_role.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )
        self.Reset = channel.unary_unary(
                '/LogReplayNode.LogReplayNode/Reset',
                request_serializer=Common__pb2.empty.SerializeToString,
                response_deserializer=Common__pb2.result.FromString,
                )


class LogReplayNodeServicer(object):
    """Missing associated documentation comment in .proto file."""

    def StartLog(self, request, context):
        """
        开始一个数据记录
        绝对路径
        result: 执行结果
        - 0: 成功
        - 1: 失败，文件格式不支持
        - 2: 失败，文件已经存在
        - 3: 失败, 创建文件失败
        - 1000: raise
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def GetLogInfo(self, request, context):
        """
        结束一个数据记录
        result: 执行结果
        - 0: 成功
        - 1000: raise
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def StopLog(self, request, context):
        """
        停止一个数据记录任务
        result: 执行结果
        - 0: 结束成功
        - 1000: reise
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DecodeLin(self, request, context):
        """
        解包一个 LIN 数据
        result: 执行结果
        -0: 解包成功
        -1000: raise
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def DecodeCan(self, request, context):
        """
        解包一个 CAN 数据
        result: 执行结果
        - 0: 解包成功
        - 1000: raise
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddLinDecodeRole(self, request, context):
        """
        添加 LIN 的解析规则
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def AddCanDecodeRole(self, request, context):
        """
        添加 CAN 的解析规则
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def Reset(self, request, context):
        """
        复位
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_LogReplayNodeServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'StartLog': grpc.unary_unary_rpc_method_handler(
                    servicer.StartLog,
                    request_deserializer=Common__pb2.file_path.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'GetLogInfo': grpc.unary_unary_rpc_method_handler(
                    servicer.GetLogInfo,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=LogReplayNode__pb2.log_info.SerializeToString,
            ),
            'StopLog': grpc.unary_unary_rpc_method_handler(
                    servicer.StopLog,
                    request_deserializer=Common__pb2.file_path.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'DecodeLin': grpc.unary_unary_rpc_method_handler(
                    servicer.DecodeLin,
                    request_deserializer=LogReplayNode__pb2.lin_message.FromString,
                    response_serializer=LogReplayNode__pb2.lin_message_decode.SerializeToString,
            ),
            'DecodeCan': grpc.unary_unary_rpc_method_handler(
                    servicer.DecodeCan,
                    request_deserializer=LogReplayNode__pb2.can_message.FromString,
                    response_serializer=LogReplayNode__pb2.can_message_decode.SerializeToString,
            ),
            'AddLinDecodeRole': grpc.unary_unary_rpc_method_handler(
                    servicer.AddLinDecodeRole,
                    request_deserializer=LogReplayNode__pb2.lin_decode_role.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'AddCanDecodeRole': grpc.unary_unary_rpc_method_handler(
                    servicer.AddCanDecodeRole,
                    request_deserializer=LogReplayNode__pb2.can_decode_role.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
            'Reset': grpc.unary_unary_rpc_method_handler(
                    servicer.Reset,
                    request_deserializer=Common__pb2.empty.FromString,
                    response_serializer=Common__pb2.result.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'LogReplayNode.LogReplayNode', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class LogReplayNode(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def StartLog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LogReplayNode.LogReplayNode/StartLog',
            Common__pb2.file_path.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def GetLogInfo(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LogReplayNode.LogReplayNode/GetLogInfo',
            Common__pb2.empty.SerializeToString,
            LogReplayNode__pb2.log_info.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def StopLog(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LogReplayNode.LogReplayNode/StopLog',
            Common__pb2.file_path.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DecodeLin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LogReplayNode.LogReplayNode/DecodeLin',
            LogReplayNode__pb2.lin_message.SerializeToString,
            LogReplayNode__pb2.lin_message_decode.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def DecodeCan(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LogReplayNode.LogReplayNode/DecodeCan',
            LogReplayNode__pb2.can_message.SerializeToString,
            LogReplayNode__pb2.can_message_decode.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddLinDecodeRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LogReplayNode.LogReplayNode/AddLinDecodeRole',
            LogReplayNode__pb2.lin_decode_role.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def AddCanDecodeRole(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LogReplayNode.LogReplayNode/AddCanDecodeRole',
            LogReplayNode__pb2.can_decode_role.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def Reset(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/LogReplayNode.LogReplayNode/Reset',
            Common__pb2.empty.SerializeToString,
            Common__pb2.result.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



import typing
from pathlib import Path

import grpc

from . import ZoneSenderData
from .ObjIo import *
from .Protos import LogReplayNode_pb2, LogReplayNode_pb2_grpc
from .BlfIo import BlfIoObjs


class LogReplayNodeClient(object):
    def __init__(self) -> None:
        '''
        ZoneSender 用于记录和回放的客户端
        '''
        self._logReplayStub = LogReplayNode_pb2_grpc.LogReplayNodeStub(
            channel=grpc.insecure_channel(
                target='{0}:{1}'.format(ZoneSenderData.LOG_REPLAY_NODE_IP, ZoneSenderData.LOG_REPLAY_NODE_PORT),
                options=ZoneSenderData.GRPC_OPTIONS
            )
        )

    def AddLinDecodeRole(
        self, 
        channels: typing.List[int],
        ldfs: typing.List[str],
        **kwargs) -> int:
        '''
        添加一个 LIN 数据的解析规则
        可以重复添加
        :param channels:list[int] LIN 通道列表
        :param ldfs:list[int] ldf 文件列表
        :return:int
            - 0: 添加成功
            - 1000: raise
        '''
        try:
            ldfs = [str(Path(x_).absolute()) for x_ in ldfs]
            res_ = self._logReplayStub.AddLinDecodeRole(LogReplayNode_pb2.lin_decode_role(
                channels = channels,
                ldfs = ldfs,
            ))
            print(res_.reason)
            return res_
        except Exception as e_:
            print('LogReplayNodeClient.AddLinDecodeRole Exception reason {0}'.format(e_))
            return 1000

    def AddCanDecodeRole(
        self,
        can_db_file_path:str,
        channels:typing.List[int],
        cluster_names:typing.List[str],
        **kwargs
        ) -> int:
        '''
        添加一个 CAN 数据的解析规则
        可以重复添加
        :param can_db_file_path:str CAN DB 文件的路径
        :param channels:list[int] LIN 通道列表
        :param ldfs:list[int] ldf 文件列表
        :return:int
            - 0: 添加成功
            - 1000: raise
        '''
        try:
            res_ = self._logReplayStub.AddCanDecodeRole(LogReplayNode_pb2.can_decode_role(
                can_db_file_path = str(Path(can_db_file_path).absolute()),
                channels = channels,
                cluster_names = cluster_names,
            ))
            print(res_.reason)
            return res_
        except Exception as e_:
            print('LogReplayNodeClient.AddCanDecodeRole Exception reason {0}'.format(e_))
            return 1000

    def Reset(self) -> int:
        '''
        复位
            - 清空解析配置文件
            - 关闭所有正在解析的文件
        :return:int
            - 0: 复位成功
            - 1000: raise
        '''
        try:
            res_ = self._logReplayStub.Reset(LogReplayNode_pb2.Common__pb2.empty())
            print(res_.reason)
            return res_.result
        except Exception as e_:
            print('LogReplayNodeClient.Reset Exception reason {0}'.format(e_))
            return 1000

    def DecodeAny(
        self,
        obj: BlfIoObjs.BlfIoStruct, 
        d_return:dict) -> int:
        '''
        根据设定的规则解包任何 BlfObj
        :param obj:BlfIoObjs.BlfIoStruct 要解包的 blf_obj
        :param d_return:dict 如果解包成功，就返回解包后的结果
        :return:int
            - 0: 解包成功
            - 1000: raise
        '''
        try:
            assert (isinstance(
                obj, 
                (BlfIoObjs.LinMessagePy, 
                BlfIoObjs.CanMessagePy, 
                BlfIoObjs.CanFdMessage64Py, 
                BlfIoObjs.CanFdMessagePy))), 'LogReplayNodeClient.DecodeAny.obj 的类型不受支持'
            return 0
        except Exception as e_:
            print('LogReplayNodeClient.DecodeAny Exception reason {0}'.format(e_))
            return 1000




# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: LogReplayNode.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from . import Common_pb2 as Common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x13LogReplayNode.proto\x12\rLogReplayNode\x1a\x0c\x43ommon.proto\";\n\x08log_info\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x0f\n\x07logging\x18\x02 \x03(\t\"8\n\x0blin_message\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\r\x12\n\n\x02id\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x03(\r\"e\n\x12lin_message_decode\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\r\x12\n\n\x02id\x18\x03 \x01(\r\x12\x12\n\ndecode_str\x18\x04 \x01(\t\"8\n\x0b\x63\x61n_message\x12\x0f\n\x07\x63hannel\x18\x01 \x01(\r\x12\n\n\x02id\x18\x02 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x03 \x03(\r\"e\n\x12\x63\x61n_message_decode\x12\x1e\n\x06result\x18\x01 \x01(\x0b\x32\x0e.Common.result\x12\x0f\n\x07\x63hannel\x18\x02 \x01(\r\x12\n\n\x02id\x18\x03 \x01(\r\x12\x12\n\ndecode_str\x18\x04 \x01(\t\"1\n\x0flin_decode_role\x12\x10\n\x08\x63hannels\x18\x01 \x03(\r\x12\x0c\n\x04ldfs\x18\x02 \x03(\t\"T\n\x0f\x63\x61n_decode_role\x12\x18\n\x10\x63\x61n_db_file_path\x18\x01 \x01(\t\x12\x10\n\x08\x63hannels\x18\x02 \x03(\r\x12\x15\n\rcluster_names\x18\x03 \x03(\t2\xfa\x03\n\rLogReplayNode\x12/\n\x08StartLog\x12\x11.Common.file_path\x1a\x0e.Common.result\"\x00\x12\x36\n\nGetLogInfo\x12\r.Common.empty\x1a\x17.LogReplayNode.log_info\"\x00\x12.\n\x07StopLog\x12\x11.Common.file_path\x1a\x0e.Common.result\"\x00\x12L\n\tDecodeLin\x12\x1a.LogReplayNode.lin_message\x1a!.LogReplayNode.lin_message_decode\"\x00\x12L\n\tDecodeCan\x12\x1a.LogReplayNode.can_message\x1a!.LogReplayNode.can_message_decode\"\x00\x12\x44\n\x10\x41\x64\x64LinDecodeRole\x12\x1e.LogReplayNode.lin_decode_role\x1a\x0e.Common.result\"\x00\x12\x44\n\x10\x41\x64\x64\x43\x61nDecodeRole\x12\x1e.LogReplayNode.can_decode_role\x1a\x0e.Common.result\"\x00\x12(\n\x05Reset\x12\r.Common.empty\x1a\x0e.Common.result\"\x00\x62\x06proto3')



_LOG_INFO = DESCRIPTOR.message_types_by_name['log_info']
_LIN_MESSAGE = DESCRIPTOR.message_types_by_name['lin_message']
_LIN_MESSAGE_DECODE = DESCRIPTOR.message_types_by_name['lin_message_decode']
_CAN_MESSAGE = DESCRIPTOR.message_types_by_name['can_message']
_CAN_MESSAGE_DECODE = DESCRIPTOR.message_types_by_name['can_message_decode']
_LIN_DECODE_ROLE = DESCRIPTOR.message_types_by_name['lin_decode_role']
_CAN_DECODE_ROLE = DESCRIPTOR.message_types_by_name['can_decode_role']
log_info = _reflection.GeneratedProtocolMessageType('log_info', (_message.Message,), {
  'DESCRIPTOR' : _LOG_INFO,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.log_info)
  })
_sym_db.RegisterMessage(log_info)

lin_message = _reflection.GeneratedProtocolMessageType('lin_message', (_message.Message,), {
  'DESCRIPTOR' : _LIN_MESSAGE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.lin_message)
  })
_sym_db.RegisterMessage(lin_message)

lin_message_decode = _reflection.GeneratedProtocolMessageType('lin_message_decode', (_message.Message,), {
  'DESCRIPTOR' : _LIN_MESSAGE_DECODE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.lin_message_decode)
  })
_sym_db.RegisterMessage(lin_message_decode)

can_message = _reflection.GeneratedProtocolMessageType('can_message', (_message.Message,), {
  'DESCRIPTOR' : _CAN_MESSAGE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.can_message)
  })
_sym_db.RegisterMessage(can_message)

can_message_decode = _reflection.GeneratedProtocolMessageType('can_message_decode', (_message.Message,), {
  'DESCRIPTOR' : _CAN_MESSAGE_DECODE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.can_message_decode)
  })
_sym_db.RegisterMessage(can_message_decode)

lin_decode_role = _reflection.GeneratedProtocolMessageType('lin_decode_role', (_message.Message,), {
  'DESCRIPTOR' : _LIN_DECODE_ROLE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.lin_decode_role)
  })
_sym_db.RegisterMessage(lin_decode_role)

can_decode_role = _reflection.GeneratedProtocolMessageType('can_decode_role', (_message.Message,), {
  'DESCRIPTOR' : _CAN_DECODE_ROLE,
  '__module__' : 'LogReplayNode_pb2'
  # @@protoc_insertion_point(class_scope:LogReplayNode.can_decode_role)
  })
_sym_db.RegisterMessage(can_decode_role)

_LOGREPLAYNODE = DESCRIPTOR.services_by_name['LogReplayNode']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LOG_INFO._serialized_start=52
  _LOG_INFO._serialized_end=111
  _LIN_MESSAGE._serialized_start=113
  _LIN_MESSAGE._serialized_end=169
  _LIN_MESSAGE_DECODE._serialized_start=171
  _LIN_MESSAGE_DECODE._serialized_end=272
  _CAN_MESSAGE._serialized_start=274
  _CAN_MESSAGE._serialized_end=330
  _CAN_MESSAGE_DECODE._serialized_start=332
  _CAN_MESSAGE_DECODE._serialized_end=433
  _LIN_DECODE_ROLE._serialized_start=435
  _LIN_DECODE_ROLE._serialized_end=484
  _CAN_DECODE_ROLE._serialized_start=486
  _CAN_DECODE_ROLE._serialized_end=570
  _LOGREPLAYNODE._serialized_start=573
  _LOGREPLAYNODE._serialized_end=1079
# @@protoc_insertion_point(module_scope)
